/**************************************************************************************
Author:			David Szybala
Program:		Materials_finalRender_Advanced.ms
Date:			11/18/09
Description:	This script allows the user to affect muliple fR materials simultaneously.
***************************************************************************************/

try (destroyDialog frRollout) catch()

(--put script into local context
	global frRollout
	local frMaterials = #()
	local frIniFile = getDir #plugcfg + "\\frMat.ini"
	local frRolloutPos
	
	local spinnerProperties = #("diffuseMultiplier","selfIllumMultiplier","reflectGlossy","reflectSamples","reflectIOR", \
										"refractGlossy","refractSamples","refractIOR","refractPriority","shadingType", \
										"specularLevel1","glossiness1","soften1","anisotropic1","orientation1", \
										"specularLevel2","glossiness2","soften2","anisotropic2","orientation2", \
										"specularLevel3","glossiness3","soften3","anisotropic3","orientation3", \
										"specularLevel4","glossiness4","soften4","anisotropic4","orientation4", \
										"roughness","anisoAlignment","anisoChannel", \
										"giSendMultiplier","giRecvMultiplier","csSendMultiplier","csRecvMultiplier", \
										"reflAbsorpionMode","reflAbsorpionStart","reflAbsorption","reflAbsorptionAmount","reflAbsorpDistance", \
										"reflBlurRadius","reflBlurSamples","anisotropic","orientation","alignment","channel", \
										"spectralAmount","spectralBalance","falloff","exitMode","threshold","environmentMode", \
										"refrAbsorpionMode","refrAbsorpionStart","refrAbsorption","refrAbsorptionAmount", \
										"iorVariance","spectralSamples","refrBlurRadius","refrBlurSamples","refrEnvironmentMode", \
										"sssScattDepth","sssAbsorption","sssAnisotropy","sssMultplier", \
										"sssDepthRed","sssDepthGreen","sssDepthBlue","sssIntSamples","sssSecRays", \
										"globalClamp","diffuseClamp","sssClamp","reflectionClamp","refractionClamp","specularClamp")
	
	local checkProperties = #("twoSided","filterShadows","useFresnel","useRefractionPriorities","useInternalReflection", \
										"useSpecHighLights","useSpecLayer1","useSpecLayer2","useSpecLayer3","useSpecLayer4", \
										"useAnisotropy1","useAnisotropy2","useAnisotropy3","useAnisotropy4", \
										"useGISendMultiplier","useGIRecvMultiplier","callGIOnBlack","useCSSendMultiplier", \
										"useCSRecvMultiplier","useReflectCaustics","useRefractCaustics", \
										"useReflAbsorption","useReflAbsorpGradient","useReflBlur","storeReflInGI", \
										"useLocalThreshold","shadeAtmospherics","blurryAffectsCaustics","affectAlpha", \
										"useRefrAbsorption","useRefrAbsorpGradient","useDispersion","useDispAbsorpGradient", \
										"useRefrBlur","storeRefrInGI","useSubSurfaceSattering","useGlobalClamp", \
										"useDiffuseClamp","useSSSClamp","useReflectionClamp","useRefractionClamp","useSpecularClamp")
										
	local colorProperties = #("diffuseColor","selfIllum","reflectFilter","refractFilter","opacity","specularColor1","specularColor2", \
										"specularColor3","specularColor4","reflAbsorpColor","specDirectColor","specGrazingColor","exitColor", \
										"environmentColor","refrAbsorpColor","refrEnvironmentColor ","sssAbsortionColor")
	
	local mapProperties = #("diffuseMap","diffusionMap","selfIllumMap","opacityMap", \
									"reflectMap","reflectBlurryMap","reflectIORMap", \
									"refractMap","refractBlurryMap","refractBlurryMap", \
									"bumpMap","MTDMap","sssDepthMap","sssAbsorptionMap", \
									"sssAbsColorMap","sssMultiplierMap","sssFilterMap","roughnessMap", \
									"specColor1Map","specLevel1Map","specGlossy1Map","anisoAmount1Map","anisoOrient1Map", \
									"specColor2Map","specLevel2Map","specGlossy2Map","anisoAmount2Map","anisoOrient2Map", \
									"specColor3Map","specLevel3Map","specGlossy3Map","anisoAmount3Map","anisoOrient3Map", \
									"specColor4Map","specLevel4Map","specGlossy4Map","anisoAmount4Map","anisoOrient4Map")
										
	local mapAmountProperties = #("diffuseMapAmount","diffusionMapAmount","selfIllumMapAmount","opacityMapAmount", \
												"reflectMapAmount","reflectBlurryMapAmount","reflectIORMapAmount", \
												"refractMapAmount","refractBlurryMapAmount","refractBlurryMapAmount", \
												"bumpMapAmount","MTDMapAmount","sssDepthMapAmount","sssAbsorptionMapAmount", \
												"sssAbsColorMapAmount","sssMultiplierMapAmount","sssFilterMapAmount","roughnessMapAmount", \
												"specColor1MapAmount","specLevel1MapAmount","specGlossy1MapAmount","anisoAmount1MapAmount","anisoOrient1MapAmount", \
												"specColor2MapAmount","specLevel2MapAmount","specGlossy2MapAmount","anisoAmount2MapAmount","anisoOrient2MapAmount", \
												"specColor3MapAmount","specLevel3MapAmount","specGlossy3MapAmount","anisoAmount3MapAmount","anisoOrient3MapAmount", \
												"specColor4MapAmount","specLevel4MapAmount","specGlossy4MapAmount","anisoAmount4MapAmount","anisoOrient4MapAmount")
												
	local mapCheckProperties = #("useDiffuseMap","useDiffusionMap","useSelfIllumMap","useOpacityMap", \
											"useReflectMap","useReflectBlurryMap","useReflectIORMap", \
											"useRefractMap","useRefractBlurryMap","useRefractIORMap", \
											"useBumpMap","useMTDMap","useSSSDepthMap","useSSSAbsorptionMap", \
											"useSSSAbsColorMap","useSSSMultiplierMap","useSSSFilterMap","useRoughnessMap", \
											"useSpecColor1Map","useSpecLevel1Map","useSpecGlossy1Map","useAnisoAmount1Map","useAnisoOrient1Map", \
											"useSpecColor2Map","useSpecLevel2Map","useSpecGlossy2Map","useAnisoAmount2Map","useAnisoOrient2Map", \
											"useSpecColor3Map","useSpecLevel3Map","useSpecGlossy3Map","useAnisoAmount3Map","useAnisoOrient3Map", \
											"useSpecColor4Map","useSpecLevel4Map","useSpecGlossy4Map","useAnisoAmount4Map","useAnisoOrient4Map")
	
	/***************************************************************************************/
	fn Sort_Array elementOne elementTwo =
	(
		case of
		(
			(elementOne.name < elementTwo.name): -1
			(elementOne.name > elementTwo.name): 1
			default: 0
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Refresh_Material_List =
	(
		frMaterials = getClassInstances fR_Advanced
		
		local frMatNames = #()
		local enableButtons = false
		
		if frMaterials.count > 0 do
		(
			qsort frMaterials Sort_Array
			for current in frMaterials do append frMatNames current.name
			frRollout.frList.items = frMatNames
			enableButtons = true
		)--end if
		
		frRollout.totalLabel.text = ("Total: " + (frMaterials.count as string))
		
		frRollout.spinnerDropDown.enabled = frRollout.spinnerSelector.enabled = \
		frRollout.checkDropDown.enabled = frRollout.checkON.enabled = frRollout.checkOFF.enabled = \
		frRollout.colorDropDown.enabled = frRollout.colorSelector.enabled = \
		frRollout.mapDropDown.enabled = frRollout.mapSelector.enabled = \
		frRollout.mapAmtDropDown.enabled = frRollout.mapAmtSelector.enabled = \
		frRollout.mapCheckDropDown.enabled = frRollout.mapCheckON.enabled = frRollout.mapCheckOFF.enabled = enableButtons
	)--end fn
	
	/***************************************************************************************/
	fn Set_Property_Value currentProperty currentValue =
	(
		case frRollout.modeRadio.state of
		(
			(1): for index in (frRollout.frList.selection as array) do setProperty frMaterials[index] currentProperty currentValue
			(2): for currentMat in frMaterials do setProperty currentMat currentProperty currentValue
			(3): for currentObj in selection do
				 (
					 if currentObj.material != undefined do
					 (
						 if (classOf currentObj.material) == fR_Advanced do setProperty currentObj.material currentProperty currentValue
					 )--end if
				 )--end for
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Check_Spinner_Value theValue =
	(
		case frRollout.spinnerDropDown.selection of
		(
			(4):theValue = (theValue as integer)
			(7):theValue = (theValue as integer)
			(9):theValue = (theValue as integer)
			(10):theValue = (theValue as integer)
			(32):theValue = (theValue as integer)
			(33):theValue = (theValue as integer)
			(38):theValue = (theValue as integer)
			(44):theValue = (theValue as integer)
			(47):theValue = (theValue as integer)
			(48):theValue = (theValue as integer)
			(51):theValue = (theValue as integer)
			(52):theValue = (theValue as integer)
			(54):theValue = (theValue as integer)
			(59):theValue = (theValue as integer)
			(61):theValue = (theValue as integer)
			(62):theValue = (theValue as integer)
			(70):theValue = (theValue as integer)
			(71):theValue = (theValue as integer)
		)--end case
		
		Set_Property_Value spinnerProperties[frRollout.spinnerDropDown.selection] theValue
	)--end fn
	
	/***************************************************************************************/
	fn Set_Spinner_Range theIndex =
	(
		case theIndex of
		(
			(1):frRollout.spinnerSelector.range = [0,9999,100] --diffuse level
			(2):frRollout.spinnerSelector.range = [0,9999,100] --self level
			(3):frRollout.spinnerSelector.range = [0,100,0] --reflection blurry
			(4):frRollout.spinnerSelector.range = [1,512,8] --reflection samples INTEGER
			(5):frRollout.spinnerSelector.range = [0,100,1.5] --reflection IOR
			(6):frRollout.spinnerSelector.range = [0,100,0] --refraction blurry
			(7):frRollout.spinnerSelector.range = [1,512,8] --refraction samples INTEGER
			(8):frRollout.spinnerSelector.range = [0,100,1.5] --refraction IOR
			(9):frRollout.spinnerSelector.range = [1,999,1] --refraction priority INTEGER
			(10):frRollout.spinnerSelector.range = [0,3,0] --shading type INTEGER
			(11):frRollout.spinnerSelector.range = [0,1000,0] --specular level
			(12):frRollout.spinnerSelector.range = [0,100,10] --specular glossiness
			(13):frRollout.spinnerSelector.range = [0,100,10] --specular soften
			(14):frRollout.spinnerSelector.range = [0,100,0] --specular anistropy
			(15):frRollout.spinnerSelector.range = [-360,360,0] --specular orientation
			(16):frRollout.spinnerSelector.range = [0,1000,0]
			(17):frRollout.spinnerSelector.range = [0,100,10]
			(18):frRollout.spinnerSelector.range = [0,100,10]
			(19):frRollout.spinnerSelector.range = [0,100,0]
			(20):frRollout.spinnerSelector.range = [-360,360,0]
			(21):frRollout.spinnerSelector.range = [0,1000,0]
			(22):frRollout.spinnerSelector.range = [0,100,10]
			(23):frRollout.spinnerSelector.range = [0,100,10]
			(24):frRollout.spinnerSelector.range = [0,100,0]
			(25):frRollout.spinnerSelector.range = [-360,360,0]
			(26):frRollout.spinnerSelector.range = [0,1000,0]
			(27):frRollout.spinnerSelector.range = [0,100,10]
			(28):frRollout.spinnerSelector.range = [0,100,10]
			(29):frRollout.spinnerSelector.range = [0,100,0]
			(30):frRollout.spinnerSelector.range = [-360,360,0]
			(31):frRollout.spinnerSelector.range = [0,100,0] --global roughness
			(32):frRollout.spinnerSelector.range = [0,4,0] --shading alignment INTEGER
			(33):frRollout.spinnerSelector.range = [1,256,1] --shading channel INTEGER
			(34):frRollout.spinnerSelector.range = [0,9999,1] --send gi
			(35):frRollout.spinnerSelector.range = [0,9999,1] --receive gi
			(36):frRollout.spinnerSelector.range = [0,9999,1] --send caustic
			(37):frRollout.spinnerSelector.range = [0,9999,1] --receive caustic
			(38):frRollout.spinnerSelector.range = [0,1,0] --reflection abs mode
			(39):frRollout.spinnerSelector.range = [0,9999,0] --reflection abs start
			(40):frRollout.spinnerSelector.range = [0,9999,1000] --reflection abs end
			(41):frRollout.spinnerSelector.range = [0,9999,1] --reflection abs amount
			(42):frRollout.spinnerSelector.range = [0,9999,1000] --max reflection distance
			(43):frRollout.spinnerSelector.range = [0,9999,4] --ultra blur radius
			(44):frRollout.spinnerSelector.range = [1,512,60] --ultra blur samples INTEGER
			(45):frRollout.spinnerSelector.range = [0,100,0] --anistropy
			(46):frRollout.spinnerSelector.range = [-360,360,0] --orientation
			(47):frRollout.spinnerSelector.range = [0,4,0] --alignment INTEGER
			(48):frRollout.spinnerSelector.range = [1,256,1] --channel INTEGER
			(49):frRollout.spinnerSelector.range = [1,100,0] --spectral amount
			(50):frRollout.spinnerSelector.range = [-100,100,0] --spectral balance
			(51):frRollout.spinnerSelector.range = [0,2,0] --brdf mode
			(52):frRollout.spinnerSelector.range = [0,2,0] --exit mode
			(53):frRollout.spinnerSelector.range = [0,100,10] --ray threshold
			(54):frRollout.spinnerSelector.range = [0,2,0] --enviornment mode
			(55):frRollout.spinnerSelector.range = [0,9999,0] --refraction abs start
			(56):frRollout.spinnerSelector.range = [0,9999,1000] --refraction abs end
			(57):frRollout.spinnerSelector.range = [0,9999,1] --refraction abs amount
			(58):frRollout.spinnerSelector.range = [0,100,0.1] --ior variance
			(59):frRollout.spinnerSelector.range = [1,512,10] --dispersion samples INTEGER
			(60):frRollout.spinnerSelector.range = [0,9999,4] --ultra blur radius
			(61):frRollout.spinnerSelector.range = [0,512,60] --ultra blur samples INTEGER
			(62):frRollout.spinnerSelector.range = [0,2,0] --environment mode
			(63):frRollout.spinnerSelector.range = [0.001,999,5] --sss depth
			(64):frRollout.spinnerSelector.range = [0.001,999,0.1] --sss abs
			(65):frRollout.spinnerSelector.range = [-100,100,75] --sss anisotropy
			(66):frRollout.spinnerSelector.range = [0.001,9999,1] --sss multiply
			(67):frRollout.spinnerSelector.range = [0,99,1] --r
			(68):frRollout.spinnerSelector.range = [0,99,1] --g
			(69):frRollout.spinnerSelector.range = [0,99,1] --b
			(70):frRollout.spinnerSelector.range = [1,512,80] --sss samples INTEGER
			(71):frRollout.spinnerSelector.range = [0,512,0] --sss rays INTEGER
			(72):frRollout.spinnerSelector.range = [0,999,4] --global clamp
			(73):frRollout.spinnerSelector.range = [0,999,4] --diffuse clamp
			(74):frRollout.spinnerSelector.range = [0,999,4] --sss clamp
			(75):frRollout.spinnerSelector.range = [0,999,4] --reflection clamp
			(76):frRollout.spinnerSelector.range = [0,999,4] --refraction clamp
			(77):frRollout.spinnerSelector.range = [0,999,4] --spec clamp
		)--end case
	)--end fn
	
	/***************************************************************************************/
	rollout frRollout "finalRender Advanced"
	(
		label totalLabel "Total: " pos:[5,5] width:150 height:15
		button updateButton "Update" pos:[150,3] width:50 height:15
		MultiListBox frList "" pos:[5,20] width:195 height:17
		
		radiobuttons modeRadio "" pos:[5,250] labels:#("List Select","All fR","Scene Select") columns:2
		
		dropDownList spinnerDropDown "" pos:[5,285] width:140 height:20 --enabled:false
		spinner spinnerSelector "" pos:[150,287] range:[0,100,1] type:#float scale:0.1 width:50 height:16 enabled:false
		
		dropDownList checkDropDown "" pos:[5,315] width:140 height:20 --enabled:false
		--checkbox checkSelector "" pos:[168,315] width:50 height:20 enabled:false
		button checkON "ON" pos:[150,317] width:25 height:15 enabled:false
		button checkOFF "OFF" pos:[175,317] width:25 height:15 enabled:false
		
		dropDownList colorDropDown "" pos:[5,345] width:140 height:20 --enabled:false
		colorPicker colorSelector "" pos:[156,345] width:34 height:20 enabled:false
		
		dropDownList mapDropDown "" pos:[5,375] width:140 height:20 --enabled:false
		mapButton mapSelector "M" pos:[160,375] width:30 height:20 enabled:false
		
		dropDownList mapAmtDropDown "" pos:[5,405] width:140 height:20 --enabled:false
		spinner mapAmtSelector "" pos:[150,407] range:[0,100,100] type:#float scale:0.1 width:50 height:16 enabled:false
		
		dropDownList mapCheckDropDown "" pos:[5,435] width:140 height:20 --enabled:false
		--checkbox mapCheckSelector "" pos:[168,435] width:50 height:20 enabled:false
		button mapCheckON "ON" pos:[150,437] width:25 height:15 enabled:false
		button mapCheckOFF "OFF" pos:[175,437] width:25 height:15 enabled:false
		
		-------------------------------------------------------------------
		on frRollout open do
		(
			local lastSelection = ""
			
			spinnerDropDown.items = #("Diffuse Level","Self-Illumination Level","Reflection Blurry","Reflection Samples","Reflection IOR", \
												"Refraction Blurry","Refraction Samples","Refraction IOR","Refraction Priority","Shading Type", \
												"Specular 1 Level","Specular 1 Glossiness","Specular 1 Soften","Specular 1 Anisotropy","Specular 1 Orientation", \
												"Specular 2 Level","Specular 2 Glossiness","Specular 2 Soften","Specular 2 Anisotropy","Specular 2 Orientation", \
												"Specular 3 Level","Specular 3 Glossiness","Specular 3 Soften","Specular 3 Anisotropy","Specular 3 Orientation", \
												"Specular 4 Level","Specular 4 Glossiness","Specular 4 Soften","Specular 4 Anisotropy","Specular 4 Orientation", \
												"Global Roughness","Shading Alignment","Shading Channel", \
												"Send GI Multiplier","Receive GI Multiplier","Send Caustic Multiplier","Receive Caustic Multiplier", \
												"Reflection Abs Mode","Reflection Abs Start","Reflection Abs End","Reflection Abs Amount","Reflection Abs Distance", \
												"Reflection Blur Radius","Reflection Blur Samples","Anisotropy","Orientation","Alignment","Channel", \
												"Spectral Amount","Spectral Balance","BRDF Mode","Exit Mode","Ray Threshold","Reflection Env Mode", \
												"Refraction Abs Mode","Refraction Abs Start","Refraction Abs End","Refraction Abs Amount", \
												"IOR Variance","Dispersion Samples","Refraction Blur Radius","Refraction Blur Samples","Refraction Env Mode", \
												"SSS Depth","SSS Absorption","SSS Anisotropy","SSS Multiplier", \
												"SSS Depth Red","SSS Depth Green","SSS Depth Blue","SSS Samples","SSS Sec Rays", \
												"Global Clamp","Diffuse Clamp","SSS Clamp","Reflection Clamp","Refraction Clamp","Specular Clamp")
			
			checkDropDown.items = #("Two Sided","Filter Shadows","Fresnel","Refract Priority","Internal Reflections", \
												"Speculars","Specular Layer 1","Specular Layer 2","Specular Layer 3","Specular Layer 4", \
												"Anisotropy 1","Anisotropy 2","Anisotropy 3","Anisotropy 4", \
												"Send GI","Receive GI","GI on Black","Send Caustics", \
												"Receive Caustics","Reflect Caustics","Refract Caustics", \
												"Reflection Absorption","Reflection Abs Gradient","Reflect Ultra Blur","Store Reflection", \
												"Ray Threshold","Consider Atmospherics","Blurry Affects Caustics","Refraction Affects Alpha", \
												"Refraction Absorption","Refraction Abs Gradient","Dispersion","Dispersion Gradient", \
												"Refraction Ultra Blur","Store Refraction","SSS","Global Clamp", \
												"Diffuse Clamp","SSS Clamp","Reflection Clamp","Refraction Clamp","Specular Clamp")
										
			colorDropDown.items = #("Diffuse","Self-Illumination","Reflection","Refraction","Opacity","Specular 1","Specular 2","Specular 3", \
												"Specular 4","Reflection Absorption","Spectral Direct","Spectral Glazing","Reflection Exit", \
												"Reflection Environment","Refraction Absorption","Refraction Environment","SSS Absorption")
			
			mapDropDown.items = #("Diffuse","Diffusion","Self-Illumination","Opacity","Reflection","Reflection Glossiness", \
													"Reflection IOR","Refraction","Refraction Glossiness","Refraction IOR","Bump","Displacement",
													"SSS Depth","SSS Absorption","SSS Absorption Color","SSS Multiplier","SSS Filter", \
													"Specular 1 Color","Specular 1 Level","Specular 1 Glossiness","Specular 1 Anisotropy","Specular 1 Orientation", \
													"Specular 2 Color","Specular 2 Level","Specular 2 Glossiness","Specular 2 Anisotropy","Specular 2 Orientation", \
													"Specular 3 Color","Specular 3 Level","Specular 3 Glossiness","Specular 3 Anisotropy","Specular 3 Orientation", \
													"Specular 4 Color","Specular 4 Level","Specular 4 Glossiness","Specular 4 Anisotropy","Specular 4 Orientation")
									
			mapAmtDropDown.items = #("Diffuse Map","Diffusion Map","Self-Illumination Map","Opacity Map","Reflection Map","Reflection Glossiness Map", \
													"Reflection IOR Map","Refraction Map","Refraction Glossiness Map","Refraction IOR Map","Bump Map","Displacement Map",
													"SSS Depth Map","SSS Absorption Map","SSS Absorption Color Map","SSS Multiplier Map","SSS Filter Map", \
													"Specular 1 Color Map","Specular 1 Level Map","Specular 1 Glossiness Map","Specular 1 Anisotropy Map","Specular 1 Orientation Map", \
													"Specular 2 Color Map","Specular 2 Level Map","Specular 2 Glossiness Map","Specular 2 Anisotropy Map","Specular 2 Orientation Map", \
													"Specular 3 Color Map","Specular 3 Level Map","Specular 3 Glossiness Map","Specular 3 Anisotropy Map","Specular 3 Orientation Map", \
													"Specular 4 Color Map","Specular 4 Level Map","Specular 4 Glossiness Map","Specular 4 Anisotropy Map","Specular 4 Orientation Map")
			
			mapCheckDropDown.items = #("Diffuse Map","Diffusion Map","Self-Illumination Map","Opacity Map","Reflection Map","Reflection Glossiness Map", \
													"Reflection IOR Map","Refraction Map","Refraction Glossiness Map","Refraction IOR Map","Bump Map","Displacement Map",
													"SSS Depth Map","SSS Absorption Map","SSS Absorption Color Map","SSS Multiplier Map","SSS Filter Map", \
													"Specular 1 Color Map","Specular 1 Level Map","Specular 1 Glossiness Map","Specular 1 Anisotropy Map","Specular 1 Orientation Map", \
													"Specular 2 Color Map","Specular 2 Level Map","Specular 2 Glossiness Map","Specular 2 Anisotropy Map","Specular 2 Orientation Map", \
													"Specular 3 Color Map","Specular 3 Level Map","Specular 3 Glossiness Map","Specular 3 Anisotropy Map","Specular 3 Orientation Map", \
													"Specular 4 Color Map","Specular 4 Level Map","Specular 4 Glossiness Map","Specular 4 Anisotropy Map","Specular 4 Orientation Map")
					
			lastSelection = getIniSetting frIniFile "Spinner" "Selection"
			if lastSelection != "" do
			(
				spinnerDropDown.selection = (lastSelection as integer)
				Set_Spinner_Range (lastSelection as integer)
			)--end if
			lastSelection = getIniSetting frIniFile "Check" "Selection"
			if lastSelection != "" do checkDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting frIniFile "Color" "Selection"
			if lastSelection != "" do colorDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting frIniFile "Map" "Selection"
			if lastSelection != "" do mapDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting frIniFile "Map Amount" "Selection"
			if lastSelection != "" do mapAmtDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting frIniFile "Map Check" "Selection"
			if lastSelection != "" do mapCheckDropDown.selection = (lastSelection as integer)
			
			if (classOf fR_Advanced) == material then Refresh_Material_List()
			else messagebox "finalRender plugin not detected." title:"ERROR"
		)--end on
		
		-------------------------------------------------------------------
		on frRollout moved pos do
			setIniSetting frIniFile "Dialog" "Position" (pos as string)
			
		-------------------------------------------------------------------
		on frRollout close do
		(
			setIniSetting frIniFile "Spinner" "Selection" (spinnerDropDown.selection as string)
			setIniSetting frIniFile "Check" "Selection" (checkDropDown.selection as string)
			setIniSetting frIniFile "Color" "Selection" (colorDropDown.selection as string)
			setIniSetting frIniFile "Map" "Selection" (mapDropDown.selection as string)
			setIniSetting frIniFile "Map Amount" "Selection" (mapAmtDropDown.selection as string)
			setIniSetting frIniFile "Map Check" "Selection" (mapCheckDropDown.selection as string)
		)--end on
		
		-------------------------------------------------------------------
		on updateButton pressed do
		(
			if (classOf fR_Advanced) == material then Refresh_Material_List()
			else messagebox "finalRender plugin not detected." title:"ERROR"
		)--end on
		
		-------------------------------------------------------------------
		on spinnerDropDown selected theIndex do Set_Spinner_Range theIndex
		
		-------------------------------------------------------------------
		on mapAmtDropDown selected theIndex do
		(
			if theIndex == 13 or theIndex == 14 then
				mapAmtSelector.range = [-1000,1000,30]
			else
				mapAmtSelector.range = [0,100,100]
		)--end on
		
		-------------------------------------------------------------------
		on spinnerSelector changed theValue do		Check_Spinner_Value theValue
		on checkON pressed do					 		Set_Property_Value checkProperties[checkDropDown.selection] true
		on checkOFF pressed do					 		Set_Property_Value checkProperties[checkDropDown.selection] false
		on colorSelector changed theColor do			Set_Property_Value colorProperties[colorDropDown.selection] theColor
		on mapSelector picked theMap do				Set_Property_Value mapProperties[mapDropDown.selection] theMap
		on mapAmtSelector changed theValue do		Set_Property_Value mapAmountProperties[mapAmtDropDown.selection] theValue
		on mapCheckON pressed do						Set_Property_Value mapCheckProperties[mapCheckDropDown.selection] true
		on mapCheckOFF pressed do						Set_Property_Value mapCheckProperties[mapCheckDropDown.selection] false
	)--end rollout
	frRolloutPos = execute (getIniSetting frIniFile "Dialog" "Position")
	if frRolloutPos == OK do frRolloutPos = [100,100]
	if frRolloutPos.x > sysinfo.desktopsize.x - 205 do frRolloutPos.x = sysinfo.desktopsize.x - 210
	if frRolloutPos.y > sysinfo.desktopsize.y - 520 do frRolloutPos.y = sysinfo.desktopsize.y - 520
	if frRolloutPos.x < 0 do frRolloutPos.x = 0 
	if frRolloutPos.y < 0 do frRolloutPos.y = 0
	createDialog frRollout 205 460 frRolloutPos.x frRolloutPos.y
)--end local context

/* properties not used
.sssRGBDepths_obsolete
.passGILight_obsolete
.overrideObjectSettings
.filterWithSurface_obsolete
.selectedSpecLayer
.sssScattering_obsolete (SSS_Scattering_Coeficient) : float
.sssDepth_obsolete (Reflectivity) : percent
*/